@@ -133,7 +133,7 @@ fn add_fetch_user_method(credentials_store: Arc<dyn CredentialsStore>) -> Handle
             return Box::new(
                 HttpResponse::BadRequest()
                     .json(ErrorResponse::bad_request(
-                        &"Failed to process request: no user id".to_string(),
+                        "Failed to process request: no user id",
                     ))
                     .into_future(),
             );
