@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,26 +12,24 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-#[cfg(feature = "rest-api-actix")]
 mod actix_web_1;
 mod resources;
 
-#[cfg(all(feature = "authorization", feature = "rest-api-actix"))]
+#[cfg(feature = "authorization")]
 use crate::rest_api::auth::authorization::Permission;
 
-#[cfg(feature = "rest-api-actix")]
 pub use actix_web_1::{
     BiomeCredentialsRestConfig, BiomeCredentialsRestConfigBuilder,
     BiomeCredentialsRestResourceProvider, BiomeCredentialsRestResourceProviderBuilder,
 };
 
-#[cfg(all(feature = "authorization", feature = "rest-api-actix"))]
+#[cfg(feature = "authorization")]
 const BIOME_USER_READ_PERMISSION: Permission = Permission::Check {
     permission_id: "biome.user.read",
     permission_display_name: "Biome user read",
     permission_description: "Allows the client to view all Biome users",
 };
-#[cfg(all(feature = "authorization", feature = "rest-api-actix"))]
+#[cfg(feature = "authorization")]
 const BIOME_USER_WRITE_PERMISSION: Permission = Permission::Check {
     permission_id: "biome.user.write",
     permission_display_name: "Biome user write",
