@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,6 +17,8 @@ use bcrypt::BcryptError;
 use std::error::Error;
 use std::fmt;
 
+use crate::error::InternalError;
+
 /// Represents CredentialsStore errors
 #[derive(Debug)]
 pub enum CredentialsStoreError {
@@ -43,6 +45,9 @@ pub enum CredentialsStoreError {
     DuplicateError(String),
     // Represents the specific case where a query returns no records
     NotFoundError(String),
+
+    /// An internal error has occurred
+    InternalError(InternalError),
 }
 
 impl Error for CredentialsStoreError {
@@ -58,6 +63,7 @@ impl Error for CredentialsStoreError {
             CredentialsStoreError::ConnectionError(err) => Some(&**err),
             CredentialsStoreError::DuplicateError(_) => None,
             CredentialsStoreError::NotFoundError(_) => None,
+            CredentialsStoreError::InternalError(source) => Some(source),
         }
     }
 }
@@ -91,6 +97,7 @@ impl fmt::Display for CredentialsStoreError {
             CredentialsStoreError::NotFoundError(ref s) => {
                 write!(f, "credentials not found: {}", s)
             }
+            CredentialsStoreError::InternalError(e) => f.write_str(&e.to_string()),
         }
     }
 }
@@ -102,6 +109,12 @@ impl From<diesel::r2d2::PoolError> for CredentialsStoreError {
     }
 }
 
+impl From<InternalError> for CredentialsStoreError {
+    fn from(err: InternalError) -> Self {
+        Self::InternalError(err)
+    }
+}
+
 /// Represents CredentialsBuilder errors
 #[derive(Debug)]
 pub enum CredentialsBuilderError {
