@@ -309,7 +309,7 @@ pub struct Service {
     service_type: String,
     node_id: String,
     arguments: Vec<(String, String)>,
-    peer_id: Option<PeerTokenPair>,
+    local_peer_id: Option<PeerTokenPair>,
 }
 
 impl Service {
@@ -332,7 +332,7 @@ impl Service {
             service_type,
             node_id,
             arguments,
-            peer_id: None,
+            local_peer_id: None,
         }
     }
 
@@ -357,16 +357,28 @@ impl Service {
     }
 
     /// Returns the local peer ID for the service
+    pub fn local_peer_id(&self) -> &Option<PeerTokenPair> {
+        &self.local_peer_id
+    }
+
+    pub fn set_local_peer_id(&mut self, peer_id: PeerTokenPair) {
+        self.local_peer_id = Some(peer_id)
+    }
+
+    pub fn remove_local_peer_id(&mut self) {
+        self.local_peer_id = None
+    }
+
     pub fn peer_id(&self) -> &Option<PeerTokenPair> {
-        &self.peer_id
+        self.local_peer_id()
     }
 
     pub fn set_peer_id(&mut self, peer_id: PeerTokenPair) {
-        self.peer_id = Some(peer_id)
+        self.set_local_peer_id(peer_id)
     }
 
     pub fn remove_peer_id(&mut self) {
-        self.peer_id = None
+        self.remove_local_peer_id()
     }
 }
 
