@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -12,9 +12,11 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+//! Dynamic service orchestration.
+
 mod builder;
 mod error;
-#[cfg(feature = "rest-api")]
+#[cfg(feature = "rest-api-actix-web-1")]
 mod rest_api;
 mod runnable;
 
@@ -38,7 +40,8 @@ use crate::protos::circuit::{
 };
 use crate::protos::prelude::*;
 use crate::service::{
-    Service, ServiceFactory, ServiceMessageContext, StandardServiceNetworkRegistry,
+    FactoryCreateError, Service, ServiceFactory, ServiceMessageContext,
+    StandardServiceNetworkRegistry,
 };
 use crate::threading::lifecycle::ShutdownHandle;
 use crate::transport::Connection;
@@ -71,9 +74,38 @@ impl std::fmt::Display for ServiceDefinition {
     }
 }
 
+/// A service that may be orchestratable.
+///
+/// This service has several stronger requirements, mainly required moving and sharing a service
+/// instance among threads.
+pub trait OrchestratableService: Service {
+    fn clone_box(&self) -> Box<dyn OrchestratableService>;
+
+    fn as_service(&self) -> &dyn Service;
+}
+
+impl Clone for Box<dyn OrchestratableService> {
+    fn clone(&self) -> Self {
+        self.clone_box()
+    }
+}
+
+/// A service factory that produces orchestratable services.
+pub trait OrchestratableServiceFactory: ServiceFactory {
+    /// Create a Service instance with the given ID, of the given type, the given circuit_id,
+    /// with the given arguments.
+    fn create_orchestratable_service(
+        &self,
+        service_id: String,
+        service_type: &str,
+        circuit_id: &str,
+        args: HashMap<String, String>,
+    ) -> Result<Box<dyn OrchestratableService>, FactoryCreateError>;
+}
+
 /// Stores a service and other structures that are used to manage it
 struct ManagedService {
-    pub service: Box<dyn Service>,
+    pub service: Box<dyn OrchestratableService>,
     pub registry: StandardServiceNetworkRegistry,
 }
 
@@ -82,14 +114,14 @@ pub struct ServiceOrchestrator {
     /// A (ServiceDefinition, ManagedService) map
     services: Arc<Mutex<HashMap<ServiceDefinition, ManagedService>>>,
     /// Factories used to create new services.
-    service_factories: Vec<Box<dyn ServiceFactory>>,
+    service_factories: Vec<Box<dyn OrchestratableServiceFactory>>,
     supported_service_types: Vec<String>,
     /// `network_sender` and `inbound_router` are used to create services' senders.
     network_sender: Sender<Vec<u8>>,
     inbound_router: InboundRouter<CircuitMessageType>,
     /// A (ServiceDefinition, ManagedService) map of services that have been stopped, but yet to
     /// be completely destroyed
-    stopped_services: Arc<Mutex<HashMap<ServiceDefinition, Box<dyn Service>>>>,
+    stopped_services: Arc<Mutex<HashMap<ServiceDefinition, Box<dyn OrchestratableService>>>>,
 
     /// `running` and `join_handles` are used to shutdown the orchestrator's background threads
     running: Arc<AtomicBool>,
@@ -104,7 +136,7 @@ impl ServiceOrchestrator {
         note = "please use `ServiceOrchestratorBuilder` instead"
     )]
     pub fn new(
-        service_factories: Vec<Box<dyn ServiceFactory>>,
+        service_factories: Vec<Box<dyn OrchestratableServiceFactory>>,
         connection: Box<dyn Connection>,
         incoming_capacity: usize,
         outgoing_capacity: usize,
@@ -155,7 +187,7 @@ impl ServiceOrchestrator {
             .ok_or(InitializeServiceError::UnknownType)?;
 
         // Create the service.
-        let mut service = factory.create(
+        let mut service = factory.create_orchestratable_service(
             service_definition.service_id.clone(),
             service_definition.service_type.as_str(),
             service_definition.circuit.as_str(),
@@ -297,7 +329,7 @@ impl ServiceOrchestrator {
             .ok_or(AddServiceError::UnknownType)?;
 
         // Create the previously stopped service.
-        let service = factory.create(
+        let service = factory.create_orchestratable_service(
             service_definition.service_id.clone(),
             service_definition.service_type.as_str(),
             service_definition.circuit.as_str(),
