@@ -174,7 +174,7 @@ fn query_list_nodes(
             .map_err(RegistryRestApiError::from)?;
         let offset_value = offset.unwrap_or(0);
         let total = nodes.len();
-        let limit_value = limit.unwrap_or_else(|| total as usize);
+        let limit_value = limit.unwrap_or(total as usize);
 
         let nodes = nodes
             .skip(offset_value)
